==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebTabGroupPaneDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebTabGroupPaneDescription } from "./WebTabGroupPaneDescription";
/**
 * @hidden
 */
export let WebTabGroupPaneDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabGroupPaneDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabGroupPaneDescriptionMetadata.a == null) {
                WebTabGroupPaneDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabGroupPaneDescriptionMetadata.c(WebTabGroupPaneDescriptionMetadata.a);
            }
            if (a.j(WebTabGroupPaneDescriptionMetadata.a)) {
                return;
            }
            a.y(WebTabGroupPaneDescriptionMetadata.a);
        }
        static c(a) {
            WebDockManagerPaneDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:TabGroupPane");
            a.item("Id", "String");
            a.item("PaneType", "(wc:Type)ExportedType:string:DockManagerPaneType");
            a.item("PaneType@names", "SplitPane;ContentPane;TabGroupPane;DocumentHost");
            a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
            a.item("Size", "Number:double");
            a.item("SelectedIndex", "Number:double");
            a.item("AllowEmpty", "Boolean");
        }
        static d(a) {
            WebTabGroupPaneDescriptionMetadata.b(a);
            a.aa("WebTabGroupPane", () => new WebTabGroupPaneDescription());
            a.z("WebTabGroupPane", WebTabGroupPaneDescriptionMetadata.a);
        }
    }
    WebTabGroupPaneDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabGroupPaneDescriptionMetadata, 'WebTabGroupPaneDescriptionMetadata');
    WebTabGroupPaneDescriptionMetadata.a = null;
    return WebTabGroupPaneDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebTabGroupPaneDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebTabGroupPaneDescription } from "./WebTabGroupPaneDescription";
/**
 * @hidden
 */
export let WebTabGroupPaneDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabGroupPaneDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabGroupPaneDescriptionMetadata.a == null) {
                WebTabGroupPaneDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabGroupPaneDescriptionMetadata.c(WebTabGroupPaneDescriptionMetadata.a);
            }
            if (a.k(WebTabGroupPaneDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebTabGroupPaneDescriptionMetadata.a);
        }
        static c(a) {
            WebDockManagerPaneDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:TabGroupPane");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Id", "String");
            a.item("PaneType", "(wc:Type)ExportedType:string:DockManagerPaneType");
            a.item("PaneType@names", "SplitPane;ContentPane;TabGroupPane;DocumentHost");
            a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
            a.item("Size", "Number:double");
            a.item("SelectedIndex", "Number:double");
            a.item("AllowEmpty", "Boolean");
        }
        static d(a) {
            WebTabGroupPaneDescriptionMetadata.b(a);
            a.ac("WebTabGroupPane", () => new WebTabGroupPaneDescription());
            a.ab("WebTabGroupPane", WebTabGroupPaneDescriptionMetadata.a);
        }
    }
    WebTabGroupPaneDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabGroupPaneDescriptionMetadata, 'WebTabGroupPaneDescriptionMetadata');
    WebTabGroupPaneDescriptionMetadata.a = null;
    return WebTabGroupPaneDescriptionMetadata;
})();
